@@ -1064,6 +1064,7 @@ TABULAR_HEADER = ['seq_id',
                   'raw_input']
 
 AIRR_HEADER = ['sequence_id',
+               'umi',
                'sequence',
                'sequence_aa',
                'rev_comp',
@@ -1072,12 +1073,17 @@ AIRR_HEADER = ['sequence_id',
                'stop_codon',
                'v_call',
                'v_gene',
+               'v_score',
                'v_identity',
+               'v_identity_aa',
                'd_call',
                'd_gene',
+               'd_score',
                'j_call',
                'j_gene',
+               'j_score',
                'j_identity',
+               'j_identity_aa',
                'c_call',
                'cdr3_length',
                'fwr1_aa',
@@ -1097,8 +1103,19 @@ AIRR_HEADER = ['sequence_id',
                'v_deletions',
                'junction',
                'junction_aa',
+               'junction_in_frame',
+               'isotype',
+               'locus',
                'v_cigar',
                'd_cigar',
                'j_cigar',
                'species',
+               'germline_database',
                'raw_input']
+
+
+
+
+
+
+
